@@ -7,6 +7,7 @@ import numpy as np
 import pandas as pd
 import seaborn as sns
 from mpl_toolkits.mplot3d import Axes3D
+import matplotlib.dates as mdates
 
 from .config import Style
 from .utils import (
@@ -14,6 +15,7 @@ from .utils import (
     margin_calc,
     to_list_if_other_array,
     make_dict,
+    dict_pretty,
 )
 
 
@@ -94,10 +96,10 @@ def adjust_axes(
     if x_axis_human_tick_labels:
         if x_axis_formatter is None:
             x_axis_formatter: str = "%Y-%m-%d"
-        xfmt = matplotlib.dates.DateFormatter(x_axis_formatter)
         ax = plt.gca()
-        ax.set_xticklabels(ax.get_xticks(), rotation=45)
-        ax.xaxis.set_major_formatter(xfmt)
+        ax.xaxis.set_major_formatter(mdates.DateFormatter(x_axis_formatter))
+        for tick_label in ax.get_xticklabels(which="major"):
+            tick_label.set(rotation=30, horizontalalignment="right")
 
 
 def apply_plot_labels(xlabel: str = "", ylabel: str = "", title: str = "", style: Style = None) -> None:
@@ -185,6 +187,9 @@ def visualize_1d_distribution(
     legend_strings: Union[Tuple[str], List[str]] = None,
     xlim: Any = None,
     ylim: Any = None,
+    describe: bool = False,
+    plot_mean: Union[bool, str] = False,
+    plot_median: Union[bool, str] = False,
     show: bool = False,
     **kwargs,
 ) -> plt.Figure:
@@ -201,11 +206,15 @@ def visualize_1d_distribution(
     :param legend_strings: override legend strings
     :param xlim: optional bound for the x-axis
     :param ylim: optional bound for the y-axis
+    :param describe: adds stats from pandas.DataFrame.describe() as a watermark
+    :param plot_mean: plots the mean as a vertical line
+    :param plot_median: plots the median as a vertical line
     :param show: set to true to trigger plt.show()
     :param kwargs: additional keyword arguments for matplotlib.pyplot.hist()
     :return: figure handle for the plot
     """
     # Set style. Overrides: kwargs > style input > Style() defaults
+    original_kwargs: dict = kwargs.copy()
     config: Style = Style(**{**Style().dict(), **make_dict(style), **make_dict(kwargs)})
     kwargs: Dict[str, Any] = {k: v for k, v in kwargs.items() if k not in config.dict()}
 
@@ -239,8 +248,25 @@ def visualize_1d_distribution(
             data_set,
             color=config.color,
             bins=hist_bins,
-            **{k: v for k, v in kwargs.items() if k != "bins"},
+            **{k: v for k, v in kwargs.items() if not any(x_ in k for x_ in ["plot", "bins"])},
         )
+        if describe:
+            description: pd.Series = pd.DataFrame({"_data_": data_set})["_data_"].describe()
+            stat_str: str = dict_pretty(
+                {stat_name: description[stat_name] for stat_name in description.keys().tolist()}
+            )
+            watermark += f"\n--- stats ---\n{stat_str}"
+            if "watermark_fontsize" not in original_kwargs:
+                config.watermark_fontsize = 12
+            if "watermark_placement" not in original_kwargs:
+                config.watermark_placement = (0.05, 0.6)
+
+        if plot_mean:
+            line_color: str = plot_mean if isinstance(plot_mean, str) else config.median_linecolor
+            plt.axvline(x=np.nanmean(data_set), color=line_color, linestyle="-")
+        if plot_median:
+            line_color: str = plot_mean if isinstance(plot_mean, str) else config.median_linecolor
+            plt.axvline(x=np.nanmedian(data_set), color=line_color, linestyle="--")
 
     # Make sure that the axes facecolor matches the figure facecolor
     plt.gca().set(facecolor=config.facecolor)
@@ -278,6 +304,7 @@ def visualize_x_y(
     watermark: str = "",
     multi: bool = None,
     legend_strings: Union[Tuple[str], List[str]] = None,
+    loc: str = None,
     xlim: Any = None,
     ylim: Any = None,
     plot_best_fit: Union[bool, int] = False,
@@ -305,6 +332,7 @@ def visualize_x_y(
     :param watermark: watermark text
     :param multi: flag to specify whether multiple traces are desired, if the automatic inference is incorrect
     :param legend_strings: override legend strings
+    :param loc: location of the legend (matplotlib.pyplot convention)
     :param plot_best_fit: whether to plot the best fit lines (specify degree, or pass True for degree 1)
     :param xlim: optional bound for the x-axis
     :param ylim: optional bound for the y-axis
@@ -418,9 +446,9 @@ def visualize_x_y(
             cbar.set_label(colorbar_label, rotation=90, fontsize=config.label_fontsize)
     if legend_strings:
         if "scatter" in types:
-            plt.legend(scatter_handles, legend_strings, fontsize=config.legend_fontsize)
+            plt.legend(scatter_handles, legend_strings, fontsize=config.legend_fontsize, loc=loc)
         elif includes_line_plot:  # scatter legend overrides plot legend for now
-            plt.legend(legend_strings, fontsize=config.legend_fontsize)
+            plt.legend(legend_strings, fontsize=config.legend_fontsize, loc=loc)
     adjust_axes(
         log_axes=log_axes,
         style=config,
