@@ -3,7 +3,8 @@ from typing import List, Any, Tuple, Callable, Dict, Union, Iterable
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
-import stumpy
+
+# import stumpy
 from matplotlib.patches import Rectangle
 from .config import Style
 from .utils import (
@@ -28,11 +29,11 @@ from .plotting import (
 )
 import pathlib
 from pydantic import BaseModel
-from sklearn.feature_selection import SelectKBest, chi2
 from tqdm.auto import tqdm
 
 # import matrixprofile
 import math
+import sys
 
 
 class SVD(BaseModel):
@@ -380,33 +381,33 @@ class VectorMultiset(PickleUtils, Style, Rosetta):
             colorbar_label=self.translate(z_axis_name),
         )
 
-    def feature_selection_univariate(
-        self,
-        target_feature_name: str,
-        input_feature_names: List[str] = None,
-        k_best: int = 3,
-        normalize: bool = True,
-        **kwargs,
-    ) -> any:
-        """Feature selection of k best using univariate methods.
-
-        :param target_feature_name: column name of the target feature
-        :param input_feature_names: column names of the input features
-        :param k_best: how many features to return
-        :param normalize: if True, scales input features to unit mean
-        :param kwargs: additional keyword arguments passed through to scikit-learn SelectKBest
-        :return: trimmed input feature data set
-        """
-        if not input_feature_names:
-            input_feature_names = [x for x in self.data.keys() if x != target_feature_name]
-        input_feature_data = self.data.loc[:, input_feature_names]
-        if normalize:
-            for fieldname in input_feature_data.keys():
-                std_dev: float = float(np.std(this_field_data := self.data.loc[:, fieldname]))
-                input_feature_data[fieldname] = [x / std_dev for x in this_field_data]
-
-        target_feature_data = self.data.loc[:, target_feature_name].to_numpy()
-        return SelectKBest(chi2, k=k_best).fit_transform(input_feature_data, target_feature_data, **kwargs)
+    # def feature_selection_univariate(
+    #     self,
+    #     target_feature_name: str,
+    #     input_feature_names: List[str] = None,
+    #     k_best: int = 3,
+    #     normalize: bool = True,
+    #     **kwargs,
+    # ) -> any:
+    #     """Feature selection of k best using univariate methods.
+    #
+    #     :param target_feature_name: column name of the target feature
+    #     :param input_feature_names: column names of the input features
+    #     :param k_best: how many features to return
+    #     :param normalize: if True, scales input features to unit mean
+    #     :param kwargs: additional keyword arguments passed through to scikit-learn SelectKBest
+    #     :return: trimmed input feature data set
+    #     """
+    #     if not input_feature_names:
+    #         input_feature_names = [x for x in self.data.keys() if x != target_feature_name]
+    #     input_feature_data = self.data.loc[:, input_feature_names]
+    #     if normalize:
+    #         for fieldname in input_feature_data.keys():
+    #             std_dev: float = float(np.std(this_field_data := self.data.loc[:, fieldname]))
+    #             input_feature_data[fieldname] = [x / std_dev for x in this_field_data]
+    #
+    #     target_feature_data = self.data.loc[:, target_feature_name].to_numpy()
+    #     return SelectKBest(chi2, k=k_best).fit_transform(input_feature_data, target_feature_data, **kwargs)
 
     def cast_to_numeric(
         self,
@@ -554,6 +555,15 @@ class VectorMultiset(PickleUtils, Style, Rosetta):
         :param kwargs: keyword arguments for stumpy.stump()
         :return: numpy array with the profile
         """
+
+        if "stumpy" not in sys.modules:
+            try:
+                import stumpy
+            except ImportError as e:
+                raise ImportError(
+                    f"Could not import stumpy. Please install if compatible with your environment.\n{e}"
+                )
+
         return stumpy.stump(self.data.loc[:, col_name].tolist(), window_size, **kwargs)
 
     def stumpy_profile_univariate(
@@ -568,6 +578,14 @@ class VectorMultiset(PickleUtils, Style, Rosetta):
         :param kwargs: keyword arguments for plots and stumpy.stump()
         :return: figure handle of the plot
         """
+        if "stumpy" not in sys.modules:
+            try:
+                import stumpy
+            except ImportError as e:
+                raise ImportError(
+                    f"Could not import stumpy. Please install if compatible with your environment.\n{e}"
+                )
+
         # Make the plot and profile
         figsize: Any = kwargs.pop("figsize", self.figsize)  # typically a 2-element tuple or list
         title: str = kwargs.pop("title", self.translate(self.name_root))
